==> python-incidentio-client-0.15.1.tar.gz: python-incidentio-client-0.15.1/incident_io_client/models/public_identity_response_body.py <==
from typing import Any, Dict, List, Type, TypeVar, cast

import attr

T = TypeVar("T", bound="PublicIdentityResponseBody")


@attr.s(auto_attribs=True)
class PublicIdentityResponseBody:
    """
    Example:
        {'name': 'Dicta inventore qui.', 'roles': ['Accusantium iure quisquam id.', 'Et excepturi enim culpa ut.',
            'Mollitia fugit consequatur.']}

    Attributes:
        name (str): The name assigned to the current API Key Example: Non sed sit quia voluptatem odit..
        roles (List[str]): Which roles have been enabled for this key. Available roles are viewer, incident_creator,
            global_access, manage_settings. Example: ['Fugiat ratione est aliquid hic quasi.', 'Sunt quo harum ut quos.',
            'Nesciunt omnis magnam earum.'].
    """

    name: str
    roles: List[str]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        roles = self.roles

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "roles": roles,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        roles = cast(List[str], d.pop("roles"))

        public_identity_response_body = cls(
            name=name,
            roles=roles,
        )

        public_identity_response_body.additional_properties = d
        return public_identity_response_body

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> python-incidentio-client-0.17.0.tar.gz: python-incidentio-client-0.17.0/incident_io_client/models/public_identity_response_body.py <==
from typing import Any, Dict, List, Type, TypeVar, cast

import attr

T = TypeVar("T", bound="PublicIdentityResponseBody")


@attr.s(auto_attribs=True)
class PublicIdentityResponseBody:
    """
    Example:
        {'name': 'Officia accusantium iure quisquam.', 'roles': ['Et excepturi enim culpa ut.', 'Mollitia fugit
            consequatur.', 'Eos et et possimus molestiae rem quia.']}

    Attributes:
        name (str): The name assigned to the current API Key Example: Aliquam eligendi cupiditate voluptatem distinctio
            ut..
        roles (List[str]): Which roles have been enabled for this key. Available roles are viewer, incident_creator,
            global_access, manage_settings. Example: ['Hic quasi.', 'Sunt quo harum ut quos.', 'Nesciunt omnis magnam
            earum.', 'Dicta inventore qui.'].
    """

    name: str
    roles: List[str]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        roles = self.roles

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "roles": roles,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        roles = cast(List[str], d.pop("roles"))

        public_identity_response_body = cls(
            name=name,
            roles=roles,
        )

        public_identity_response_body.additional_properties = d
        return public_identity_response_body

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
